@@ -93,9 +93,10 @@ void LGTV1::populateProtocol(
   addKey("subtitle", Captions_Key, 0x39, 8); // "cc", "subtitle/ffw"
   addKey("up", Up_Key, 0x40, 8);
   addKey("down", Down_Key, 0x41, 8);
+  addKey("my apps", AppsMenu_Key, 0x42, 8);
   addKey("menu", Menu_Key, 0x43, 8); // "setup menu", "Home"
   addKey("ok", Select_Key, 0x44, 8);
-  addKey("qmenu", Unmapped_Key, 0x45, 8);
+  addKey("qmenu", QuickMenu_Key, 0x45, 8);
   addKey("-", Dash_Key, 0x4C, 8);
   addKey("video", PictureMode_Key, 0x4D, 8); // "apc", "PSM", "picture mode"
   addKey("TV/PC", LDInput_Key, 0x50, 8); // This is a hack
@@ -199,6 +200,7 @@ void LGTV1a::populateProtocol(
 
   LGTV1::populateProtocol(guiObject);
 
+  addKey("Back", Back_Key, 0x28, 8);
   addKey("*", Unmapped_Key, 0x39, 8);
   addKey("exit", Exit_Key, 0x5B, 8);
 //  addKey("pop", Unmapped_Key, 0x61, 8);
@@ -269,6 +271,7 @@ void LGTV1c::populateProtocol(
 //  addKey("Mark", Unmapped_Key, 0x1E, 8); // This is probably an error
 //  addKey("3DOption", Unmapped_Key, 0x45, 8); // also probably error
 //  addKey("List", Unmapped_Key, 0x4C, 8); // also odd
+  addKey("Back", Back_Key, 0x28, 8);
   addKey("info", Info_Key, 0x55, 8);
   addKey("Premium", Unmapped_Key, 0x56, 8);
   addKey("WIDGETS", Unmapped_Key, 0x58, 8);
