@@ -113,7 +113,7 @@ void SamsungTV1::populateProtocol(
   addKey("Play/Pause", Pause_Key, 0x47, 8);
   addKey("Fast Forward", FastForward_Key, 0x48, 8);
   addKey("Record", Record_Key, 0x49, 8);
-  addKey("Tools", Unmapped_Key, 0x4B, 8);
+  addKey("Tools", ToolsMenu_Key, 0x4B, 8);
   addKey("Guide", Guide_Key, 0x4F, 8);
   addKey("RETURN", Unmapped_Key, 0x58, 8);
   addKey("Up", Up_Key, 0x60, 8);
@@ -137,7 +137,7 @@ void SamsungTV1::populateProtocol(
   addKey("Component 2", Component2Input_Key, 0x88, 8);
   addKey("HDMI", HDMIInput_Key, 0x8B, 8);
   addKey("WISELINK", Unmapped_Key, 0x8C, 8); // "W.Link", "Media.P"
-  addKey("D.MENU", DiscMenu_Key, 0x8E, 8); // "D-Net Menu"
+  addKey("D.MENU", Unmapped_Key, 0x8E, 8); // "D-Net Menu"
   addKey("Internet", Unmapped_Key, 0x93, 8);
   addKey("E.Mode", Unmapped_Key, 0x94, 8);
   addKey("ANYNET", Unmapped_Key, 0x97, 8);
