@@ -157,7 +157,7 @@ void SonyTV1::populateProtocol(
   addSIRC15Key("FFORWARD", FastForward_Key, 0x97, 0x1C);
   addSIRC15Key("DOT", Unmapped_Key, 0x97, 0x1D);
   addSIRC15Key("RETURN", Unmapped_Key, 0x97, 0x23); // exit?
-  addSIRC15Key("TOOLS", Unmapped_Key, 0x97, 0x36); // "OPTIONS"
+  addSIRC15Key("TOOLS", ToolsMenu_Key, 0x97, 0x36); // "OPTIONS"
   addSIRC15Key("PREVIOUS", Previous_Key, 0x97, 0x3C);
   addSIRC15Key("NEXT", Next_Key, 0x97, 0x3D);
   addSIRC15Key("REPLAY", Replay_Key, 0x97, 0x79);
