@@ -44,9 +44,13 @@ enum PIRKeyName
   Right_Key,
   Select_Key,
   Exit_Key,
+  Back_Key,
   PageUp_Key,
   PageDown_Key,
   Guide_Key,
+  QuickMenu_Key,
+  AppsMenu_Key,
+  ToolsMenu_Key,
 
   // Number keys:
   Zero_Key,
